# majordomo-ai
This is a API specification for Majordomo AI

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import majordomo_ai
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import majordomo_ai
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import majordomo_ai
from majordomo_ai.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost:/25001
# See configuration.py for a list of all supported configuration parameters.
configuration = majordomo_ai.Configuration(
    host = "http://localhost:/25001"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): bearerAuth
configuration = majordomo_ai.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with majordomo_ai.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = majordomo_ai.AdminApi(api_client)
    app_profile = majordomo_ai.AppProfile() # AppProfile | 

    try:
        # Create app profile.
        api_response = api_instance.create_app_profile(app_profile)
        print("The response of AdminApi->create_app_profile:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AdminApi->create_app_profile: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:/25001*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminApi* | [**create_app_profile**](docs/AdminApi.md#create_app_profile) | **POST** /app_profiles | Create app profile.
*AdminApi* | [**create_model_profile**](docs/AdminApi.md#create_model_profile) | **POST** /model_profiles | Create model profile.
*AdminApi* | [**create_user**](docs/AdminApi.md#create_user) | **POST** /users | Add user.
*AdminApi* | [**create_worker**](docs/AdminApi.md#create_worker) | **POST** /workers | Create worker node.
*AdminApi* | [**create_workspace**](docs/AdminApi.md#create_workspace) | **POST** /workspaces | Create workspace.
*AdminApi* | [**delete_app_profiles**](docs/AdminApi.md#delete_app_profiles) | **DELETE** /app_profiles | Delete app profile.
*AdminApi* | [**delete_model_profiles**](docs/AdminApi.md#delete_model_profiles) | **DELETE** /model_profiles | Delete model profile.
*AdminApi* | [**delete_user**](docs/AdminApi.md#delete_user) | **DELETE** /users | Delete user.
*AdminApi* | [**delete_workers**](docs/AdminApi.md#delete_workers) | **DELETE** /workers | Delete worker nodes.
*AdminApi* | [**delete_workspaces**](docs/AdminApi.md#delete_workspaces) | **DELETE** /workspaces | Delete workspace.
*AdminApi* | [**get_allowed_profiles**](docs/AdminApi.md#get_allowed_profiles) | **GET** /allowed_profiles | Get permitted profiles for a specific user.
*AdminApi* | [**get_app_profiles**](docs/AdminApi.md#get_app_profiles) | **GET** /app_profiles | Get app profiles.
*AdminApi* | [**get_model_profiles**](docs/AdminApi.md#get_model_profiles) | **GET** /model_profiles | Get model profiles.
*AdminApi* | [**get_user_list**](docs/AdminApi.md#get_user_list) | **GET** /user_list | Get list of all users.
*AdminApi* | [**get_users**](docs/AdminApi.md#get_users) | **GET** /users | Get users list.
*AdminApi* | [**get_workers**](docs/AdminApi.md#get_workers) | **GET** /workers | Get worker nodes.
*AdminApi* | [**get_workspaces**](docs/AdminApi.md#get_workspaces) | **GET** /workspaces | Get workspaces.
*AdminApi* | [**update_app_profile**](docs/AdminApi.md#update_app_profile) | **PUT** /app_profiles | Update app profile.
*AdminApi* | [**update_model_profile**](docs/AdminApi.md#update_model_profile) | **PUT** /model_profiles | Update model profile.
*AdminApi* | [**update_user**](docs/AdminApi.md#update_user) | **PUT** /users | Update user.
*AdminApi* | [**update_worker**](docs/AdminApi.md#update_worker) | **PUT** /workers | Update worker node.
*AdminApi* | [**update_workspace**](docs/AdminApi.md#update_workspace) | **PUT** /workspaces | Update workspace.
*InferenceApi* | [**create_inference_profile**](docs/InferenceApi.md#create_inference_profile) | **POST** /inference_profiles | Create inference profile.
*InferenceApi* | [**delete_inference_profiles**](docs/InferenceApi.md#delete_inference_profiles) | **DELETE** /inference_profiles | Delete inference profile.
*InferenceApi* | [**get_inference_profiles**](docs/InferenceApi.md#get_inference_profiles) | **GET** /inference_profiles | Get inference profiles.
*InferenceApi* | [**inference_profile_command**](docs/InferenceApi.md#inference_profile_command) | **POST** /inference_profile_command/workspace/{workspace}/name/{name}/command/{command} | Send a command to inference pipeline.
*InferenceApi* | [**update_inference_profile**](docs/InferenceApi.md#update_inference_profile) | **PUT** /inference_profiles | Update inference profile.
*IngestApi* | [**create_data_store**](docs/IngestApi.md#create_data_store) | **POST** /data_stores | Create a data store.
*IngestApi* | [**create_ingest_pipeline**](docs/IngestApi.md#create_ingest_pipeline) | **POST** /ingest_pipelines | Create ingest pipeline.
*IngestApi* | [**data_store_ingest**](docs/IngestApi.md#data_store_ingest) | **POST** /data_store_ingest | Data store ingestion.
*IngestApi* | [**data_store_upload**](docs/IngestApi.md#data_store_upload) | **POST** /data_store_upload | Data store ingest local file.
*IngestApi* | [**delete_data_stores**](docs/IngestApi.md#delete_data_stores) | **DELETE** /data_stores | Delete data store.
*IngestApi* | [**delete_ingest_pipelines**](docs/IngestApi.md#delete_ingest_pipelines) | **DELETE** /ingest_pipelines | Delete ingest pipeline.
*IngestApi* | [**delete_vector_store_files**](docs/IngestApi.md#delete_vector_store_files) | **DELETE** /delete_vector_store_files/workspace/{workspace}/data-store-name/{data-store-name}/files/{files} | Delete vector stores information.
*IngestApi* | [**get_data_stores**](docs/IngestApi.md#get_data_stores) | **GET** /data_stores | List data stores.
*IngestApi* | [**get_ingest_pipelines**](docs/IngestApi.md#get_ingest_pipelines) | **GET** /ingest_pipelines | Get ingest pipeline.
*IngestApi* | [**get_vector_stores**](docs/IngestApi.md#get_vector_stores) | **GET** /vector_stores | Get vector stores information.
*IngestApi* | [**run_ingest_pipeline**](docs/IngestApi.md#run_ingest_pipeline) | **POST** /ingest_pipeline_run/workspace/{workspace}/data-store/{data_store}/name/{name} | Run ingest pipeline.
*IngestApi* | [**update_data_store**](docs/IngestApi.md#update_data_store) | **PUT** /data_stores | Update data store.
*IngestApi* | [**update_ingest_pipeline**](docs/IngestApi.md#update_ingest_pipeline) | **PUT** /ingest_pipelines | Update ingest pipeline.
*MonitorApi* | [**create_monitor_profile**](docs/MonitorApi.md#create_monitor_profile) | **POST** /monitor_profiles | Create monitor profile.
*MonitorApi* | [**delete_monitor_profiles**](docs/MonitorApi.md#delete_monitor_profiles) | **DELETE** /monitor_profiles | Delete monitor profiles.
*MonitorApi* | [**get_aggregate_stats**](docs/MonitorApi.md#get_aggregate_stats) | **GET** /aggregate_stats | Get token statistics.
*MonitorApi* | [**get_data_count**](docs/MonitorApi.md#get_data_count) | **GET** /data_count | Get the total count of various entities in the workspace.
*MonitorApi* | [**get_logs**](docs/MonitorApi.md#get_logs) | **GET** /logs | Get logs.
*MonitorApi* | [**get_monitor_profiles**](docs/MonitorApi.md#get_monitor_profiles) | **GET** /monitor_profiles | Get monitor profiles.
*MonitorApi* | [**get_token_stats**](docs/MonitorApi.md#get_token_stats) | **GET** /token_stats | Get token statistics.
*MonitorApi* | [**get_topk_stats**](docs/MonitorApi.md#get_topk_stats) | **GET** /topk_stats | Get token statistics.
*MonitorApi* | [**update_monitor_profile**](docs/MonitorApi.md#update_monitor_profile) | **PUT** /monitor_profiles | Update monitor profile.
*QueryApi* | [**create_chat_info**](docs/QueryApi.md#create_chat_info) | **POST** /chat_info | Create a chat info entry.
*QueryApi* | [**create_chat_message**](docs/QueryApi.md#create_chat_message) | **POST** /chat_messages | Create a chat message entry.
*QueryApi* | [**create_query_pipeline**](docs/QueryApi.md#create_query_pipeline) | **POST** /query_pipelines | Create query pipeline.
*QueryApi* | [**data_store_query**](docs/QueryApi.md#data_store_query) | **POST** /data_store_query | Query data store.
*QueryApi* | [**delete_chat_info**](docs/QueryApi.md#delete_chat_info) | **DELETE** /chat_info | Delete chat info entry.
*QueryApi* | [**delete_chat_messages**](docs/QueryApi.md#delete_chat_messages) | **DELETE** /chat_messages | Delete a specific chat message
*QueryApi* | [**delete_query_pipelines**](docs/QueryApi.md#delete_query_pipelines) | **DELETE** /query_pipelines | Delete query pipelines.
*QueryApi* | [**get_chat_info**](docs/QueryApi.md#get_chat_info) | **GET** /chat_info | Chat info information for a user.
*QueryApi* | [**get_chat_messages**](docs/QueryApi.md#get_chat_messages) | **GET** /chat_messages | Chat message information for a particular chat.
*QueryApi* | [**get_query_pipelines**](docs/QueryApi.md#get_query_pipelines) | **GET** /query_pipelines | Get query pipelines.
*QueryApi* | [**run_query_pipeline**](docs/QueryApi.md#run_query_pipeline) | **POST** /query_pipeline_run | Run query pipeline.
*QueryApi* | [**update_chat_info**](docs/QueryApi.md#update_chat_info) | **PUT** /chat_info | Update chat info parameters such as name or add a bunch of chat messages.
*QueryApi* | [**update_query_pipeline**](docs/QueryApi.md#update_query_pipeline) | **PUT** /query_pipelines | Update query pipeline.
*WorkflowApi* | [**create_workflow**](docs/WorkflowApi.md#create_workflow) | **POST** /workflows | Create workflow.
*WorkflowApi* | [**delete_workflows**](docs/WorkflowApi.md#delete_workflows) | **DELETE** /workflows | Delete workflow.
*WorkflowApi* | [**get_workflows**](docs/WorkflowApi.md#get_workflows) | **GET** /workflows | Get workflows.
*WorkflowApi* | [**run_workflow**](docs/WorkflowApi.md#run_workflow) | **POST** /workflow_run | Run query pipeline.
*WorkflowApi* | [**update_workflow**](docs/WorkflowApi.md#update_workflow) | **PUT** /workflows | Update workflow.


## Documentation For Models

 - [AggregateStats](docs/AggregateStats.md)
 - [AggregateStatsInfo](docs/AggregateStatsInfo.md)
 - [AllowedProfiles](docs/AllowedProfiles.md)
 - [AppProfile](docs/AppProfile.md)
 - [AppProfileInfo](docs/AppProfileInfo.md)
 - [AppProfiles](docs/AppProfiles.md)
 - [AppTypes](docs/AppTypes.md)
 - [ChatEntry](docs/ChatEntry.md)
 - [ChatInfo](docs/ChatInfo.md)
 - [ChatInfoList](docs/ChatInfoList.md)
 - [ChatInfoResponse](docs/ChatInfoResponse.md)
 - [ChatMessage](docs/ChatMessage.md)
 - [ChatMessages](docs/ChatMessages.md)
 - [ChunkingStep](docs/ChunkingStep.md)
 - [DataCount](docs/DataCount.md)
 - [DataStore](docs/DataStore.md)
 - [DataStoreInfo](docs/DataStoreInfo.md)
 - [DataStoreIngest](docs/DataStoreIngest.md)
 - [DataStoreQuery](docs/DataStoreQuery.md)
 - [DataStoreScope](docs/DataStoreScope.md)
 - [DataStoreTypes](docs/DataStoreTypes.md)
 - [DataStores](docs/DataStores.md)
 - [DeleteResponse](docs/DeleteResponse.md)
 - [DeploymentCommands](docs/DeploymentCommands.md)
 - [DeploymentSpec](docs/DeploymentSpec.md)
 - [DeploymentStatus](docs/DeploymentStatus.md)
 - [DeploymentTypes](docs/DeploymentTypes.md)
 - [DownloadAndParseFileStep](docs/DownloadAndParseFileStep.md)
 - [FileExtractor](docs/FileExtractor.md)
 - [FileExtractors](docs/FileExtractors.md)
 - [GenerateAppQueryStep](docs/GenerateAppQueryStep.md)
 - [InferenceApis](docs/InferenceApis.md)
 - [InferenceProfile](docs/InferenceProfile.md)
 - [InferenceProfileCommandResponse](docs/InferenceProfileCommandResponse.md)
 - [InferenceProfileInfo](docs/InferenceProfileInfo.md)
 - [InferenceProfiles](docs/InferenceProfiles.md)
 - [IngestParams](docs/IngestParams.md)
 - [IngestPipeline](docs/IngestPipeline.md)
 - [IngestPipelineInfo](docs/IngestPipelineInfo.md)
 - [IngestPipelines](docs/IngestPipelines.md)
 - [IngestResponse](docs/IngestResponse.md)
 - [IngestTypes](docs/IngestTypes.md)
 - [LlmQueryStep](docs/LlmQueryStep.md)
 - [LogInfo](docs/LogInfo.md)
 - [LogLevels](docs/LogLevels.md)
 - [Logs](docs/Logs.md)
 - [LookupVectordbStep](docs/LookupVectordbStep.md)
 - [Metadata](docs/Metadata.md)
 - [ModelProfile](docs/ModelProfile.md)
 - [ModelProfileInfo](docs/ModelProfileInfo.md)
 - [ModelProfileScope](docs/ModelProfileScope.md)
 - [ModelProfiles](docs/ModelProfiles.md)
 - [ModelProviders](docs/ModelProviders.md)
 - [ModelSources](docs/ModelSources.md)
 - [ModelSpec](docs/ModelSpec.md)
 - [MonitorAccessInfo](docs/MonitorAccessInfo.md)
 - [MonitorAccessKey](docs/MonitorAccessKey.md)
 - [MonitorProfile](docs/MonitorProfile.md)
 - [MonitorProfileInfo](docs/MonitorProfileInfo.md)
 - [MonitorProfiles](docs/MonitorProfiles.md)
 - [MonitorProviders](docs/MonitorProviders.md)
 - [NoSQLResponse](docs/NoSQLResponse.md)
 - [QueryModes](docs/QueryModes.md)
 - [QueryParams](docs/QueryParams.md)
 - [QueryPipeline](docs/QueryPipeline.md)
 - [QueryPipelineInfo](docs/QueryPipelineInfo.md)
 - [QueryPipelineRun](docs/QueryPipelineRun.md)
 - [QueryPipelines](docs/QueryPipelines.md)
 - [QueryResponse](docs/QueryResponse.md)
 - [QueryTypes](docs/QueryTypes.md)
 - [RunAppQueryStep](docs/RunAppQueryStep.md)
 - [SQLResponse](docs/SQLResponse.md)
 - [SelectWorkflowStep](docs/SelectWorkflowStep.md)
 - [SummarizeDoc](docs/SummarizeDoc.md)
 - [SupportedOperations](docs/SupportedOperations.md)
 - [TokenStats](docs/TokenStats.md)
 - [TokenStatsInfo](docs/TokenStatsInfo.md)
 - [TopkStats](docs/TopkStats.md)
 - [TopkStatsInfo](docs/TopkStatsInfo.md)
 - [UpdateVectordbStep](docs/UpdateVectordbStep.md)
 - [User](docs/User.md)
 - [UserInfo](docs/UserInfo.md)
 - [UserScope](docs/UserScope.md)
 - [Users](docs/Users.md)
 - [VectorStoreInfo](docs/VectorStoreInfo.md)
 - [VectorStoreStatusTypes](docs/VectorStoreStatusTypes.md)
 - [VectorStores](docs/VectorStores.md)
 - [Worker](docs/Worker.md)
 - [WorkerInfo](docs/WorkerInfo.md)
 - [Workers](docs/Workers.md)
 - [Workflow](docs/Workflow.md)
 - [WorkflowInfo](docs/WorkflowInfo.md)
 - [WorkflowProviders](docs/WorkflowProviders.md)
 - [WorkflowRun](docs/WorkflowRun.md)
 - [WorkflowStep](docs/WorkflowStep.md)
 - [Workflows](docs/Workflows.md)
 - [Workspace](docs/Workspace.md)
 - [WorkspaceInfo](docs/WorkspaceInfo.md)
 - [Workspaces](docs/Workspaces.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (JWT)


## Author




